Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Dependency ¶
type Dependency struct {
Platform string
Organisation string
Repo string
PackageName string
Version string
CurrentVersion *string
PackageManager string
PackageFilePath string
}
func (Dependency) DependencyDetails ¶ added in v0.4.0
func (d Dependency) DependencyDetails() string
type DependencyUpdate ¶ added in v0.14.0
type DependencyUpdate struct {
Dependency
NewVersion string
UpdateType string
}
type SBOMDependency ¶ added in v0.38.0
type SBOMDependency struct {
Platform string
Organisation string
Repo string
PackageName string
Version *string
CurrentVersion *string
PackageType string
}
SBOMDependency defines the domain model for all representations of Software Bill of Materials (SBOM) derived package dependencies, which is consistent across all supported types of SBOMs
Click to show internal directories.
Click to hide internal directories.